@@ -160,9 +160,13 @@ MRPWorkflow <- R6::R6Class(
         stop("model_spec$intercept must be a list with a single element named 'intercept'.")
       }
 
-
       # check prior syntax for all effects
       effects_w_priors <- unlist(model_spec)
+      names(effects_w_priors) <- purrr::map_chr(
+        names(effects_w_priors),
+        ~ strsplit(.x, split = "\\.")[[1]][2]
+      )
+
       bools <- effects_w_priors %>%
         purrr::map_lgl(function(s) .clean_prior_syntax(s) %>% .check_prior_syntax())
 
@@ -194,18 +198,28 @@ MRPWorkflow <- R6::R6Class(
             paste(omit_vars$nested, collapse = ", ")))
       }
 
-      # check if interactions can be assigned structured prior
-      ints_w_struct <- names(model_spec$interaction[model_spec$interaction == "structured"])
-      valid_ints_w_struct <- .filter_interactions(
+      # check if effects can be assigned structured prior
+      ints_w_struct <- names(effects_w_priors[effects_w_priors == "structured"])
+      valid_ints_w_struct <- .interactions_for_structured(
         interactions = ints_w_struct,
         fixed_effects = names(model_spec$fixed),
         data = private$mrpdat_$input
       )
       invalid_ints_w_struct <- setdiff(ints_w_struct, valid_ints_w_struct)
       if (length(invalid_ints_w_struct) > 0) {
-        stop(paste0("The following interactions cannot be assigned structured prior: ",
+        stop(paste0("The following effects cannot be assigned structured prior: ",
             paste(invalid_ints_w_struct, collapse = ", ")))
       }
+
+      # check if effects can be assigned ICAR or BYM2 prior
+      vars_w_icar <- names(effects_w_priors[effects_w_priors %in% c("icar", "bym2")])
+      valid_vars_w_icar <- intersect(vars_w_icar, .const()$vars$geo) %>%
+        setdiff(names(model_spec$fixed))
+      invalid_vars_w_icar <- setdiff(vars_w_icar, valid_vars_w_icar)
+      if (length(invalid_vars_w_icar) > 0) {
+        stop(paste0("The following effects cannot be assigned ICAR or BYM2 prior: ",
+            paste(invalid_vars_w_icar, collapse = ", ")))
+      }
     },
 
     assert_model = function(model) {
@@ -1129,9 +1143,17 @@ MRPWorkflow$set("public", "estimate_map", estimate_map)
 #'
 #' - normal(mu, sigma)
 #' - student_t(nu, mu, sigma)
-#' - structured*
+#' - structured
+#' - icar
+#' - bym2
 #'
-#' The last one is a custom prior syntax for the structured prior distribution developed by [Si et al. (2020)](https://arxiv.org/abs/1707.08220).
+#' The structured prior distribution developed by [Si et al. (2020)](https://arxiv.org/abs/1707.08220), which can be assigned to three types of two-way interactions:
+#' 
+#' - Two categorical variables (both with more than two levels)
+#' - One categorical variable (with more than two levels) and one binary variable
+#' - One categorical variable (with more than two levels) and one continuous variable
+#' 
+#' The spatial prior options (ICAR and BYM2) are useful when data contain geographic units (e.g., ZIP codes, counties, states) with spatial structure, specifically when observations exhibit correlation among neighboring regions. For details about the implementation and usage, see [Spatial prior specification in shinymrp](https://mrp-interface.github.io/shinymrp/articles/spatial-prior.html).
 #'
 #' The following default prior distributions are assigned to effects with empty strings (`""`)
 #' in the model specification list:
